* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [SCIM Provisioning](https://help.sap.com/docs/leanix/ea/scim-provisioning)
  * Configuring SCIM in Okta
